"""
This file 'implements' the constructors required by 
https://www.python.org/dev/peps/pep-0249/#type-objects-and-constructors
"""

from datetime import date as Date
from datetime import time as Time
from datetime import datetime as Timestamp